[Scummvm-cvs-logs] SF.net SVN: scummvm:[53027] scummvm/branches/branch-1-2-0

dreammaster at users.sourceforge.net dreammaster at users.sourceforge.net
Tue Oct 5 11:16:15 CEST 2010


Revision: 53027
          http://scummvm.svn.sourceforge.net/scummvm/?rev=53027&view=rev
Author:   dreammaster
Date:     2010-10-05 09:16:15 +0000 (Tue, 05 Oct 2010)

Log Message:
-----------
LURE: Backport of #3060480 - Ratpouch alternating between rooms

Modified Paths:
--------------
    scummvm/branches/branch-1-2-0/NEWS
    scummvm/branches/branch-1-2-0/engines/lure/hotspots.cpp

Modified: scummvm/branches/branch-1-2-0/NEWS
===================================================================
--- scummvm/branches/branch-1-2-0/NEWS	2010-10-05 09:14:18 UTC (rev 53026)
+++ scummvm/branches/branch-1-2-0/NEWS	2010-10-05 09:16:15 UTC (rev 53027)
@@ -87,6 +87,10 @@
    - Implemented formerly missing recreation of some in game items.
    - Added support for playing Kyrandia 3 with the original CD file layout.
 
+ LURE:
+   - Fixed bug where Goewin could get stuck in the Weregate
+   - Fixed issue with Ratpouch repeatedly moving between two rooms
+
  Parallaction:
    - Made part one of The Big Red Adventure completable.
 

Modified: scummvm/branches/branch-1-2-0/engines/lure/hotspots.cpp
===================================================================
--- scummvm/branches/branch-1-2-0/engines/lure/hotspots.cpp	2010-10-05 09:14:18 UTC (rev 53026)
+++ scummvm/branches/branch-1-2-0/engines/lure/hotspots.cpp	2010-10-05 09:16:15 UTC (rev 53027)
@@ -4032,12 +4032,14 @@
 
 		if (!h.currentActions().isEmpty()) {
 			if (h.startRoomNumber() != 0) {
 				// If character isn't already returning to starting room, start them doing so
 				if (!h.currentActions().bottom().hasSupportData() ||
 					(h.currentActions().bottom().supportData().action() != RETURN)) {
 					// Start follower returning
+					Hotspot *playerHotspot = res.getActiveHotspot(PLAYER_ID);
 					h.currentActions().clear();
-					h.currentActions().addFront(RETURN, h.startRoomNumber(), 0, 0);
+					h.currentActions().addFront(RETURN, playerHotspot->roomNumber(), 0, 0);
 				}
 			}
 
@@ -4032,12 +4032,14 @@
 		if (!h.currentActions().isEmpty()) {
 			if (h.startRoomNumber() != 0) {
-				// If character isn't already returning to starting room, start them doing so
+				// If character isn't already returning to starting room, redirect them to the
+				// player's current room
 				if (!h.currentActions().bottom().hasSupportData() ||
 					(h.currentActions().bottom().supportData().action() != RETURN)) {


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list